/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mnenhy.
 *
 * The Initial Developer of the Original Code is Karsten Düsterloh <kd@mnenhy.de>.
 *
 * Portions created by the Initial Developer are Copyright © 2002-2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// +-
// |  These functions are overloaded here:
// |    initializeHeaderViewTables()
// |    UpdateMessageHeaders()
// |    syncGridColumnWidths() [TB3 only]
// |    UpdateExpandedMessageHeaders() [TB3 only]
// |    messageHeaderSink.onStartHeaders()
// |    messageHeaderSink.processHeaders(headerNames, headerValues, numHeaders, dontCollectAddress)
// |  Last checked for changes: 2010-02-02
// +-
Components.utils.import("resource://mnenhy/mnenhy.js");


function initializeHeaderViewTables()
{
  goMnenhy.headers.SetCurrentWindow(window);
  goMnenhy.headers.InitializeHeaderViewTables();
}
function UpdateMessageHeaders()
{
  goMnenhy.headers.SetCurrentWindow(window);
  goMnenhy.headers.UpdateMessageHeaders();
}


// TB3 renamed some functions, because they dropped their collapsed headers!
function UpdateExpandedMessageHeaders()
{
  // only called by TB3!
  UpdateMessageHeaders();
}


function MnenhyOnStartHeadersWrapper()
{
  goMnenhy.headers.SetCurrentWindow(window);
  goMnenhy.headers.OnStartHeaders();
}
messageHeaderSink.onStartHeaders = MnenhyOnStartHeadersWrapper; // named for Enigmail (see .xul)

messageHeaderSink.processHeaders =
function(arHeaderNames, arHeaderValues, aHeaderCountOrDontCollectAddress, abDontCollectAddress)
{
  goMnenhy.headers.SetCurrentWindow(window);
  goMnenhy.headers.ProcessHeadersNew(arHeaderNames, arHeaderValues, aHeaderCountOrDontCollectAddress);
}


// need to remember last header view mode to avoid flashing
// (this variable HAS TO EXIST for every mail window!)
let giMnenhyHeaderView = -1;


// load necessary subscripts
if (    ("goMnenhy" in this)
     && ("headers" in goMnenhy)
     && (!("InitMsgHdrViewOverlay" in goMnenhy.headers))
   )
{
  if (goMnenhy.Include("chrome://mnenhy-headers/content/mnenhy-headers-msgHdrViewOverlay.js", goMnenhy.headers))
  {
    giMnenhyHeaderView = goMnenhy.headers.gkiViewDirty;
    goMnenhy.headers.InitMsgHdrViewOverlay(goMnenhy);
  }
}


// TB3 autocalculates the header grid column widths in order to align them
// we need to overlay this to take care of the toggle view button
function syncGridColumnWidths() 
{
/* deactivated for now, we don't use expandedHeadersTopBox anymore in TB
  let oNameColumn1 = document.getElementById("expandedHeadersNameColumn");
  let oNameColumn2 = document.getElementById("expandedHeaders2NameColumn");

  // reset the minimum widths to 0 so that clientWidth will return the
  // preferred intrinsic width of each column
  oNameColumn1.minWidth = oNameColumn2.minWidth = 0;

  // set minWidth on the smaller of the two columns to be the width of the
  // larger of the two
  // we include the toggle view button width into nameColumn
  let iDelta = oNameColumn1.boxObject.x - oNameColumn2.boxObject.x;
  let iNameColumn1Width = oNameColumn1.clientWidth;
  let iNameColumn2Width = oNameColumn2.clientWidth;
  let iColumn1Width = iNameColumn1Width + iDelta;
  let iColumn2Width = iNameColumn2Width;
  if (iColumn1Width > iColumn2Width)
  {
    iNameColumn2Width     = iColumn1Width;
    oNameColumn2.minWidth = iNameColumn2Width;
  }
  else if (iColumn1Width < iColumn2Width)
  {
    iNameColumn1Width     = iColumn2Width - iDelta;
    oNameColumn1.minWidth = iNameColumn1Width;
  }

  // between 3.1 and 3.2, TB changed the headerpane layout *again*
  // hence we force the grid column width here
  let oValueColumn1 = document.getElementById("expandedHeadersValueColumn");
  let oValueColumn2 = document.getElementById("expandedHeaders2ValueColumn");
  oValueColumn1.maxWidth = oValueColumn2.maxWidth = 0;

  let oHeaderBox = document.getElementById("expandedHeaderView");
  let oTopBox = document.getElementById("expandedHeadersTopBox");
  if (oTopBox)
  {
    // grab the available space, subtract the grid's name column
    // and a small gap to compensate for vanishing scrollbars
    let iRowWidth = oHeaderBox.clientWidth - iNameColumn1Width - 20;
    for (let o = oTopBox.firstChild; o; o = o.nextSibling)
    {
      // subtract all other widths but the grid's
      if ((o.nodeType == Node.ELEMENT_NODE) && (o.id != "expandedHeaders"))
        iRowWidth -= o.clientWidth;
    }
    // correct the width of the grid's value column
    oValueColumn1.maxWidth = iRowWidth;
  }

  let oBottomBox = document.getElementById("expandedHeadersBottomBox");
  if (oBottomBox)
  {
    // grab the available space, subtract the grid's name column
    // and a small gap to compensate for vanishing scrollbars
    let iRowWidth = oHeaderBox.clientWidth - iNameColumn2Width - 20;
    for (let o = oBottomBox.firstChild; o; o = o.nextSibling)
    {
      // subtract all other widths but the grid's
      if ((o.nodeType == Node.ELEMENT_NODE) && (o.id != "expandedHeaders2"))
        iRowWidth -= o.clientWidth;
    }
    // correct the width of the grid's value column
    oValueColumn2.maxWidth = iRowWidth;

    // sadly, correcting the width of the grid's value column doesn't work -
    // we need to set it on each cell
    let oRows = document.getElementById("expandedHeader2Rows");
    if (oRows && oRows.childNodes.length)
    {
      for (let o = oRows.firstChild; o; o = o.nextSibling)
      {
        let oAnonNodes = document.getAnonymousNodes(o.lastChild);
        if (oAnonNodes)
        {
          let oHTML = oAnonNodes[oAnonNodes.length - 1].firstChild;
          if (oHTML && (oHTML.localName == "html") && (iRowWidth >= 0))
          {
            let sStyle = "max-width: " + iRowWidth + "px!important;";
            // need to correct both elements for TB 3.0/3.1
            oHTML.setAttribute("style", sStyle);
            oHTML.firstChild.setAttribute("style", sStyle);
            // force repaint to correct the width
            oHTML.hidden = true;
            oHTML.hidden = false;
          }
        }
      }
    }
  }
*/
}
